.. _dsl:

DSL
===

.. py:module:: elasticsearch.dsl

Search
------
.. autoclass:: Search
   :inherited-members:
   :members:

Multi-Search
------------
.. autoclass:: MultiSearch
   :inherited-members:
   :members:

Document
--------
.. autoclass:: Document
   :inherited-members:
   :members:

Index
-----
.. autoclass:: Index
   :inherited-members:
   :members:

Mapping
-------
.. autoclass:: Mapping
   :inherited-members:
   :members:

Faceted Search
--------------
.. autoclass:: FacetedSearch
   :inherited-members:
   :members:

Update by Query
---------------
.. autoclass:: UpdateByQuery
   :inherited-members:
   :members:

